# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Scope-Guard
Version:	0.21
Release:	24.%{__distinit}%{__distvers}
Summary:	Lexically scoped resource management
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Scope-Guard
Source0:	https://cpan.metacpan.org/modules/by-module/Scope/Scope-Guard-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) 
# Module Runtime
BuildRequires:	perl(Carp) 
BuildRequires:	perl(Exporter) 
BuildRequires:	perl(strict) 
BuildRequires:	perl(warnings) 
# Test Suite
BuildRequires:	perl(Test::More) 
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module provides a convenient way to perform cleanup or other forms of
resource management at the end of a scope. It is particularly useful when
dealing with exceptions: the Scope::Guard constructor takes a reference to
a subroutine that is guaranteed to be called even if the thread of
execution is aborted prematurely. This effectively allows lexically-scoped
"promises" to be made that are automatically honored by Perl's garbage
collector.

%prep
%setup -q -n Scope-Guard-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README t/
%{perl_vendorlib}/Scope/
%{_mandir}/man3/Scope::Guard.3*

%changelog
* Fri Mar 31 2023 Paul Howarth <paul@city-fan.org> - 0.21-24
- Use SPDX-format license tag
- Use author-indepentdent source URL

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.21-11
- Perl 5.30 rebuild

* Fri Apr 13 2018 Paul Howarth <paul@city-fan.org> - 0.21-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep 23 2016 Paul Howarth <paul@city-fan.org> - 0.21-3
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jul 20 2015 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Remove useless use of UNIVERSAL::isa (CPAN RT#105948)
- Classify buildreqs by usage

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 0.20-14
- Perl 5.22 rebuild

* Sat Jun 30 2012 Paul Howarth <paul@city-fan.org> - 0.20-6
- BR: perl(Carp) and perl(Exporter)
- Drop redundant buildreqs perl(Test::Pod) and perl(Test::Pod::Coverage)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 0.20-3
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.20-2
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 17 2010 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Raise exception if guards are created anonymously (void context)
- Dix dist tag for RHEL-6 Beta

* Fri Mar 26 2010 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12 (fix link in README)

* Fri Mar 26 2010 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11 (add guard() and scope_guard(); doc tweak)

* Wed Feb 17 2010 Paul Howarth <paul@city-fan.org> - 0.03-7
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Mon Aug 10 2009 Paul Howarth <paul@city-fan.org> - 0.03-6
- Import from Fedora

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.03-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.03-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.03-3
- Rebuild for new perl

* Mon Nov 26 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.03-2
- Bump

* Tue Sep 18 2007 Chris Weyl <cweyl@alumni.drew.edu> - 0.03-1
- Specfile autogenerated by cpanspec 1.71
